Struct parquet::file::metadata::ColumnChunkMetaData [−][src]
pub struct ColumnChunkMetaData { /* fields omitted */ }Metadata for a column chunk.
Methods
impl ColumnChunkMetaData[src]
impl ColumnChunkMetaDataRepresents common operations for a column chunk.
pub fn file_path(&self) -> Option<&String>[src]
pub fn file_path(&self) -> Option<&String>File where the column chunk is stored.
If not set, assumed to belong to the same file as the metadata. This path is relative to the current file.
pub fn file_offset(&self) -> i64[src]
pub fn file_offset(&self) -> i64Byte offset in file_path().
pub fn column_type(&self) -> Type[src]
pub fn column_type(&self) -> TypeType of this column. Must be primitive.
pub fn column_path(&self) -> &ColumnPath[src]
pub fn column_path(&self) -> &ColumnPathPath (or identifier) of this column.
pub fn column_descr(&self) -> &ColumnDescriptor[src]
pub fn column_descr(&self) -> &ColumnDescriptorDescriptor for this column.
pub fn column_descr_ptr(&self) -> ColumnDescPtr[src]
pub fn column_descr_ptr(&self) -> ColumnDescPtrReference counted clone of descriptor for this column.
pub fn encodings(&self) -> &Vec<Encoding>[src]
pub fn encodings(&self) -> &Vec<Encoding>All encodings used for this column.
pub fn num_values(&self) -> i64[src]
pub fn num_values(&self) -> i64Total number of values in this column chunk.
pub fn compression(&self) -> Compression[src]
pub fn compression(&self) -> CompressionCompression for this column.
pub fn compressed_size(&self) -> i64[src]
pub fn compressed_size(&self) -> i64Returns the total compressed data size of this column chunk.
pub fn uncompressed_size(&self) -> i64[src]
pub fn uncompressed_size(&self) -> i64Returns the total uncompressed data size of this column chunk.
pub fn data_page_offset(&self) -> i64[src]
pub fn data_page_offset(&self) -> i64Returns the offset for the column data.
pub fn has_index_page(&self) -> bool[src]
pub fn has_index_page(&self) -> boolReturns true if this column chunk contains a index page, false otherwise.
pub fn index_page_offset(&self) -> Option<i64>[src]
pub fn index_page_offset(&self) -> Option<i64>Returns the offset for the index page.
pub fn has_dictionary_page(&self) -> bool[src]
pub fn has_dictionary_page(&self) -> boolReturns true if this column chunk contains a dictionary page, false otherwise.
pub fn dictionary_page_offset(&self) -> Option<i64>[src]
pub fn dictionary_page_offset(&self) -> Option<i64>TODO: add statistics Returns the offset for the dictionary page, if any.